==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ScatterPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolylineSeriesDescription } from "./ScatterPolylineSeriesDescription";
/**
 * @hidden
 */
var ScatterPolylineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeriesDescriptionMetadata, _super);
    function ScatterPolylineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterPolylineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterPolylineSeriesDescriptionMetadata.a == null) {
            ScatterPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterPolylineSeriesDescriptionMetadata.c(ScatterPolylineSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterPolylineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterPolylineSeriesDescriptionMetadata.a);
        StyleDescriptionMetadata.d(a);
    };
    ScatterPolylineSeriesDescriptionMetadata.c = function (a) {
        ShapeSeriesBaseDescriptionMetadata.c(a);
        a.item("ShapeStyle", "ExportedType:Style");
    };
    ScatterPolylineSeriesDescriptionMetadata.d = function (a) {
        ScatterPolylineSeriesDescriptionMetadata.b(a);
        a.aa("ScatterPolylineSeries", function () { return new ScatterPolylineSeriesDescription(); });
        a.z("ScatterPolylineSeries", ScatterPolylineSeriesDescriptionMetadata.a);
    };
    ScatterPolylineSeriesDescriptionMetadata.$t = markType(ScatterPolylineSeriesDescriptionMetadata, 'ScatterPolylineSeriesDescriptionMetadata');
    ScatterPolylineSeriesDescriptionMetadata.a = null;
    return ScatterPolylineSeriesDescriptionMetadata;
}(Base));
export { ScatterPolylineSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ScatterPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolylineSeriesDescription } from "./ScatterPolylineSeriesDescription";
/**
 * @hidden
 */
var ScatterPolylineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeriesDescriptionMetadata, _super);
    function ScatterPolylineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterPolylineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterPolylineSeriesDescriptionMetadata.a == null) {
            ScatterPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterPolylineSeriesDescriptionMetadata.c(ScatterPolylineSeriesDescriptionMetadata.a);
        }
        if (a.k(ScatterPolylineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(ScatterPolylineSeriesDescriptionMetadata.a);
        StyleDescriptionMetadata.d(a);
    };
    ScatterPolylineSeriesDescriptionMetadata.c = function (a) {
        ShapeSeriesBaseDescriptionMetadata.c(a);
        a.item("ShapeStyle", "ExportedType:Style");
    };
    ScatterPolylineSeriesDescriptionMetadata.d = function (a) {
        ScatterPolylineSeriesDescriptionMetadata.b(a);
        a.ac("ScatterPolylineSeries", function () { return new ScatterPolylineSeriesDescription(); });
        a.ab("ScatterPolylineSeries", ScatterPolylineSeriesDescriptionMetadata.a);
    };
    ScatterPolylineSeriesDescriptionMetadata.$t = markType(ScatterPolylineSeriesDescriptionMetadata, 'ScatterPolylineSeriesDescriptionMetadata');
    ScatterPolylineSeriesDescriptionMetadata.a = null;
    return ScatterPolylineSeriesDescriptionMetadata;
}(Base));
export { ScatterPolylineSeriesDescriptionMetadata };
